===============
 API Reference
===============


Interfaces
==========

.. automodule:: zope.sendmail.interfaces

Delivery Implementations
========================

.. automodule:: zope.sendmail.delivery

SMTP Mailer
===========

.. automodule:: zope.sendmail.mailer

Maildir support
===============

.. automodule:: zope.sendmail.maildir

Queued Mail
===========

.. automodule:: zope.sendmail.queue

Vocabulary
==========

.. automodule:: zope.sendmail.vocabulary

ZCML Directives
===============

.. automodule:: zope.sendmail.zcml
